@@ -9,6 +9,8 @@
 */
 
 #include "attachmenteditdialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "attachmenticonview.h"
 #include "config-enterprise.h"
 #include "ui_attachmenteditdialog.h"
@@ -26,14 +28,6 @@ using namespace IncidenceEditorNG;
 
 AttachmentEditDialog::AttachmentEditDialog(AttachmentIconItem *item, QWidget *parent, bool modal)
     : QDialog(parent)
-    ,
-#if KDEPIM_ENTERPRISE_BUILD
-    mAttachment(KCalendarCore::Attachment('\0'))
-// use the non-uri constructor
-// as we want inline by default
-#else
-    mAttachment(KCalendarCore::Attachment(QString()))
-#endif
     , mItem(item)
     , mUi(new Ui::AttachmentEditDialog)
 {
@@ -71,8 +65,7 @@ AttachmentEditDialog::AttachmentEditDialog(AttachmentIconItem *item, QWidget *pa
         mUi->mInlineCheck->setEnabled(true);
         mUi->mStackedWidget->setCurrentIndex(1);
         KFormat format;
-        mUi->mSizeLabel->setText(
-            QStringLiteral("%1 (%2)").arg(format.formatByteSize(item->attachment().size()), QLocale().toString(item->attachment().size())));
+        mUi->mSizeLabel->setText(u"%1 (%2)"_s.arg(format.formatByteSize(item->attachment().size()), QLocale().toString(item->attachment().size())));
     }
 
     connect(mUi->mInlineCheck, &QCheckBox::checkStateChanged, this, &AttachmentEditDialog::inlineChanged);
