@@ -7,8 +7,6 @@
 
 #include "attendeeeditor.h"
 
-#include "incidenceeditor_debug.h"
-
 using namespace IncidenceEditorNG;
 
 AttendeeEditor::AttendeeEditor(QWidget *parent)
@@ -21,13 +19,13 @@ AttendeeEditor::AttendeeEditor(QWidget *parent)
 
 void AttendeeEditor::slotLineAdded(KPIM::MultiplyingLine *line)
 {
-    auto *att = qobject_cast<AttendeeLine *>(line);
+    auto att = qobject_cast<AttendeeLine *>(line);
     if (!att) {
         return;
     }
 
     connect(att, qOverload<>(&AttendeeLine::changed), this, &AttendeeEditor::slotCalculateTotal);
-    connect(att, qOverload<const KCalendarCore::Attendee &, const KCalendarCore::Attendee &>(&AttendeeLine:: changed), this, &AttendeeEditor::changed);
+    connect(att, qOverload<const KCalendarCore::Attendee &, const KCalendarCore::Attendee &>(&AttendeeLine::changed), this, &AttendeeEditor::changed);
     connect(att, &AttendeeLine::editingFinished, this, &AttendeeEditor::editingFinished);
 }
 
@@ -38,7 +36,7 @@ void AttendeeEditor::slotCalculateTotal()
 
     const QList<KPIM::MultiplyingLine *> listLines = lines();
     for (KPIM::MultiplyingLine *line : listLines) {
-        auto *att = qobject_cast<AttendeeLine *>(line);
+        auto att = qobject_cast<AttendeeLine *>(line);
         if (att) {
             if (att->isEmpty()) {
                 ++empty;
@@ -56,9 +54,9 @@ void AttendeeEditor::slotCalculateTotal()
 
 AttendeeData::List AttendeeEditor::attendees() const
 {
-    const QVector<KPIM::MultiplyingLineData::Ptr> dataList = allData();
+    const QList<KPIM::MultiplyingLineData::Ptr> dataList = allData();
     AttendeeData::List attList; // clazy:exclude=inefficient-qlist
-    //qCDebug(INCIDENCEEDITOR_LOG) << "num attendees:" << dataList.size();
+    // qCDebug(INCIDENCEEDITOR_LOG) << "num attendees:" << dataList.size();
     for (const KPIM::MultiplyingLineData::Ptr &datum : dataList) {
         AttendeeData::Ptr att = qSharedPointerDynamicCast<AttendeeData>(datum);
         if (!att) {
@@ -83,7 +81,9 @@ void AttendeeEditor::setActions(AttendeeLine::AttendeeActions actions)
 {
     const QList<KPIM::MultiplyingLine *> listLines = lines();
     for (KPIM::MultiplyingLine *line : listLines) {
-        auto *att = qobject_cast<AttendeeLine *>(line);
+        auto att = qobject_cast<AttendeeLine *>(line);
         att->setActions(actions);
     }
 }
+
+#include "moc_attendeeeditor.cpp"
