@@ -24,11 +24,10 @@ public:
     {
     }
 
-public:
     Ui::EventOrTodoDesktop *mUi = nullptr;
     int mOrigPercentCompleted = -1;
 
-public: // slots
+    // slots
     void sliderValueChanged(int);
 };
 
@@ -38,13 +37,12 @@ void IncidenceCompletionPriorityPrivate::sliderValueChanged(int value)
         mOrigPercentCompleted = -1;
     }
 
-    mUi->mCompletedLabel->setText(QStringLiteral("%1%").arg(value));
+    mUi->mCompletedLabel->setText(u"%1%"_s.arg(value));
     q->checkDirtyStatus();
 }
 
 IncidenceCompletionPriority::IncidenceCompletionPriority(Ui::EventOrTodoDesktop *ui)
-    : IncidenceEditor()
-    , d(new IncidenceCompletionPriorityPrivate(this))
+    : d(new IncidenceCompletionPriorityPrivate(this))
 {
     Q_ASSERT(ui != nullptr);
     setObjectName("IncidenceCompletionPriority"_L1);
@@ -55,7 +53,7 @@ IncidenceCompletionPriority::IncidenceCompletionPriority(Ui::EventOrTodoDesktop
     d->mUi->mCompletionPriorityWidget->hide();
     d->mUi->mTaskLabel->hide();
     const QFontMetrics metrics(d->mUi->mCompletedLabel->font());
-    d->mUi->mCompletedLabel->setMinimumWidth(metrics.boundingRect(QStringLiteral("100%")).width());
+    d->mUi->mCompletedLabel->setMinimumWidth(metrics.boundingRect(u"100%"_s).width());
     d->mUi->mTaskSeparator->hide();
 
     connect(d->mUi->mCompletionSlider, &QSlider::valueChanged, this, [this](int val) {
